Available File Readers
======================

File readers are implemented using a Python namespace plugin system. We would
be happy to add file readers to support more ptychography instruments.

- Common File Formats
    - Coherent X-ray Imaging (\*.cxi)
    - Comma-Separated Values (\*.csv)
    - EPICS Multi-Dimensional Archive (\*.mda)
    - NumPy Binary Files (\*.npy, \*.npz)
    - PtychoShelves (\*.mat, \*.h5, \*.hdf5)
    - Ptychodus Product (\*.h5, \*.hdf5, \*.npz)
    - Space-Separated Values (\*.txt)
    - Tagged Image File Format (\*.tif, \*.tiff)
- Advanced Photon Source (APS) Instruments
    - 2-ID-D Bionanoprobe (BNP)
    - 2-ID-D Microprobe
    - 2-ID-E Microprobe
    - 4-ID Polarization Modulation Spectroscopy (Polar)
    - 9-ID Coherent Surface Scattering Imaging (CSSI)
    - 12-ID-E Ptycho-SAXS
    - 19-ID In-Situ Nanoprobe (ISN)
    - 26-ID CNM/APS Hard X-ray Nanoprobe (HXN)
    - 31-ID-E LYNX
    - 33-ID PtychoProbe
    - 33-ID Velociprobe
- Linac Coherent Light Source (LCLS) Instruments
    - Hutch 1.3: X-ray Pump Probe (XPP)
- MAX IV Instruments
    - NanoMAX Diffraction Endstation (\*.h5, \*.hdf5)
- National Synchrotron Light Source II (NSLS-II)
    - NSLS-II MATLAB Format (\*.mat)
- Swiss Light Source (SLS) Instruments
    - X12SA: Coherent Small-Angle X-ray Scattering (cSAXS)
